From 2baeac116abef9d5bcb748c687577d16dce868a0 Mon Sep 17 00:00:00 2001
From: Thomas Bruederli <thomas@roundcube.net>
Date: Thu, 16 Jan 2014 08:17:08 -0500
Subject: [PATCH] Fix sorting and paging in cross-folder searches

---
 program/lib/Roundcube/rcube_imap.php |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/program/lib/Roundcube/rcube_imap.php b/program/lib/Roundcube/rcube_imap.php
index 0cf34b2..e265946 100644
--- a/program/lib/Roundcube/rcube_imap.php
+++ b/program/lib/Roundcube/rcube_imap.php
@@ -952,7 +952,7 @@
             $search_set = $this->search_set;
 
             $this->sort_field = null;
-            $this->page_size = 100;  // limit to 100 messages per folder
+            $this->page_size = 1000;  // fetch up to 1000 matching messages per folder
 
             $a_msg_headers = array();
             foreach ($search_set->sets as $resultset) {
@@ -970,7 +970,7 @@
 
             // sort headers
             if (!$this->threading && !empty($a_msg_headers)) {
-                $a_msg_headers = $this->conn->sortHeaders($a_msg_headers, $this->sort_field, $this->sort_order);
+                $a_msg_headers = $this->conn->sortHeaders($a_msg_headers, $sort_field, $this->sort_order);
             }
 
             // only return the requested part of the set

--
Gitblit v1.9.1